## 期货合约涨跌停价格（盘前）

接口：ft_limit

描述：获取所有期货合约每天的涨跌停价格及最低保证金率，数据开始于2005年。

限量：单次最大获取4000行数据，可以通过日期、合约代码等参数循环获取所有历史

积分：用户积5000积分可调取，积分获取方法具体请参阅积分获取办法 

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | N | 合约代码 |
| trade_date | str | N | 交易日期（格式：YYYYMMDD） |
| start_date | str | N | 开始日期 |
| end_date | str | N | 结束日期 |
| cont | str | N | 合约代码（例如：cont='CU') |
| exchange | str | N | 交易所代码 （例如：exchange='DCE') |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| trade_date | str | Y | 交易日期 |
| ts_code | str | Y | TS股票代码 |
| name | str | Y | 合约名称 |
| up_limit | float | Y | 涨停价 |
| down_limit | float | Y | 跌停价 |
| m_ratio | float | Y | 最低交易保证金率（%） |
| cont | str | Y | 合约代码 |
| exchange | str | Y | 交易所代码 |

接口示例

```python
pro = ts.pro_api()

#获取单日全部期货合约涨跌停价格
df = pro.ft_limit(trade_date='20250213')

#获取单个品种所有合约涨跌停价格
df = pro.ft_limit(cont='CU')
```

数据样例

```python
trade_date     ts_code     name      up_limit down_limit m_ratio cont exchange
0     20250213   A2503.DCE  连豆一2503   4229.000   3751.000   7.000    A      DCE
```